=========
pip-check
=========

Gives you a quick overview of all installes packages and their update status.
Very much like `pip list -o` but with colors. Inspired by `npm-check`_ though
lacks most of its features (yet).

.. _npm-check: https://www.npmjs.com/package/npm-check

.. image:: http://d.pr/i/1e7wJ.png

Installation and Usage
----------------------

::

    $ pip install pip-check
    $ pip-check

Changelog
---------

v0.1 (2016-02-06):
    Very first version, and yet with very limited features.
